// Example of a custom key handler that checks an
// ethernet MAC address against what's stated in
// a custom key, for Windows.  Pass an instance of
// this as the custom key handler into the 
// EzLicenseInfo.checkLicenseKey API call.
// At the time of key generation, set the custom key
// to the customer's stated mac address as reported
// by the DOS command "ipconfig /all".
// Similarly, on Unix / Linux systems, do an "ifconfig"
// instead, and parse for a MAC address having colon-
// separated fields.  Or combine the two for a poor man's
// platform independence.
// Note: this mechanism isn't designed to protect you from
// spoofing by a determined rogue programmer, who can quite easily
// create a fake "ipconfig"/"ifconfig" program that spews
// out a MAC address corresponding to a key known to be valid
// (but the rogue would have to have access to such a key and
// be able to decompose it, which would require access to the
// key owner's user name as well).
// Note further that this code is not platform independent,
// which is why it is available as sample code and not an
// integral part of the (100 % Pure Java) product.

import com.vs.ezlicrun.*;
import java.util.*;
import java.io.*;
import java.text.*;

public class WinMacAddrHandler implements EzLicCustomLicenseInterface {
	
	public int checkCustomKeyCode(String valStr, Object ctx) 
			throws EzLicExceptionBase
	{
		String realMac = null;
		try {
			BufferedReader rdr =
				new BufferedReader(
					new InputStreamReader(
						Runtime.getRuntime().exec("ipconfig /all").getInputStream()));
			String line = null;
			while ((line = rdr.readLine()) != null) {
				line = line.trim();
				if (line.indexOf("Physical Address") >= 0) {
					StringTokenizer st = new StringTokenizer(line, ":");
					if (st.hasMoreTokens()) {
						st.nextToken();
						if (st.hasMoreTokens()) {
							// the real maccoy
							realMac = st.nextToken();
						}
					}
				}
			}
			if (realMac == null)
				throw new Exception("What! ipconfig /all didn't work??");
		} catch (Exception eek) {
			EzLicExceptionBase.throwLicenseException(
					EzLicExceptionBase.EZLIC_EXC_INTERNAL,
						"Got unexpected exception: " +
						eek.getMessage());
		}
		if (!realMac.equalsIgnoreCase(valStr))
			EzLicExceptionBase.throwLicenseException(
				EzLicExceptionBase.EZLIC_EXC_INVALID_HOST_USER_NET, 
				"Unlicensed MAC " + realMac);
		return 0; // return success with no warnings
	}
}
